// SPDX-License-Identifier: MIT

modeSelect();
const manual = document.getElementById("manual_setting");
if (manual !== null) {
    manual.style.display="none";
}
essidSelect();
let focus_flag = false;

function modeSelect() {
    const mode = document.mode_form.mode;
    const sta = document.getElementById("sta_setting");
    const ap = document.getElementById("ap_setting");
    for(var i = 0; i < mode.length; i++) {
        if(mode[i].checked) {
            if (mode[i].value == "sta") {
                sta.style.display = "block";
                ap.style.display = "none";
            } else {
                sta.style.display = "none";
                ap.style.display = "block";
            }
        }
    }
}

function methodSelect() {
    const method = document.wlan_form.method;
    const manual = document.getElementById("manual_setting");
    for(var i = 0; i < method.length; i++) {
        if(method[i].checked) {
            if (method[i].value == "manual") {
                manual.style.display = "block";
            } else {
                manual.style.display = "none";
            }
        }
    }
}

function hwmodeSelect() {
    const hwmode = document.getElementById("hw_mode");
    const channel = document.getElementById("channel");

    while (channel.options.length) {
        channel.options.remove(0)
    }
    if (hwmode.value == "g") {
        for (let i = 1; i <= 13; i++) {
            channel.options.add(new Option(i));
        }
    } else {
        // hwmode.value == "a"
        for (let i = 36; i <= 48; i += 4) {
            channel.options.add(new Option(i));
        }
    }
}

function essidSelect() {
    const essid = document.getElementById("essid");
    if (essid === null) {
        return;
    }
    const essidField = document.getElementById("other_essid_field");
    const otherEssid = document.getElementById("other_essid");

    if (essid.value == "その他") {
        essidField.style.display = "block";
        otherEssid.setAttribute("required", "");
    } else {
        essidField.style.display = "none";
        otherEssid.removeAttribute("required");
    }

    let savedid = document.querySelectorAll("label[name=saved_ssid]");
    const messageOverwrite = document.getElementById("overwrite_message");
    messageOverwrite.style.display = "none";
    for(let i = 0; i < savedid.length; i++){
        if (essid.value == savedid[i].innerHTML){
            messageOverwrite.style.display = "block";
            break;
        }
    }
}

function onsubmitAPHandler() {
    const wlan_con_ssid = document.getElementById("wlan_con_ssid");
    if (wlan_con_ssid.innerText !== "--") {
        if (!window.confirm('WLANを切断する必要があります。 よろしいですか？')) {
            return false;
        }
    }
    showLoader();
    return true;
}

const background_scan = {
    scan: false,
    timeout: false,
    set: function(time) {
        this.timeout = true;
        scan_timeout = setTimeout(pollSSID, time);
    },
    overwrite: function(time) {
        if (this.timeout) clearTimeout(scan_timeout);
        this.set(time);
    },
    started: function () {
        this.scan = true;
        this.timeout = false;
        if (focus_flag) {
            document.getElementById('wlan_load').style.visibility = "visible";
        }
    },
    finished: function () {
        this.scan = false;
        document.getElementById('wlan_load').style.visibility = "hidden";
    },
}

function appendSSID(placeHolder, data) {
    for (ssid of data) {
        if (!placeHolder.querySelector('[value="'+ssid.id.replace(/["\\]/g, '\\$&')+'"]')) {
            const element = document.createElement('div');
            element.classList.add('item');

            const input = document.createElement('input');
            input.type = "radio";
            input.name = "essid_list";
            input.value = ssid.id;
            input.id = "essid-" + ssid.id.replace(/["\\]/g, '\\$&');
            input.setAttribute("onclick", "change_essid()");

            const label = document.createElement('label');
            label.htmlFor = input.id;
            label.innerHTML = ssid.id;

            const img = new Image();
            img.src = "static/wlan/images/wlan_signal-" + ssid.strength + ".png";

            label.prepend(img);
            element.appendChild(input);
            element.appendChild(label);
            placeHolder.appendChild(element);
        }
    }
}

const pollSSID = async () => {
    background_scan.started();
    ssid_list = document.getElementById('essid_dropdown');
    if (ssid_list) {
        const response = await fetch('/wlan_scan');
        const scanned_ssid = await response.json();
        appendSSID(ssid_list, scanned_ssid);

        if(focus_flag) background_scan.set(3000);
        else background_scan.set(30000);
    }
    background_scan.finished();
}

window.addEventListener('load', (event) => {
    if (document.getElementById('essid') && !background_scan.timeout) {
        background_scan.set(100);
    }
});

document.getElementById('essid').addEventListener("focusin", (event) => {
    focus_flag = true;
    if (!background_scan.scan) background_scan.overwrite(100);
    else document.getElementById('wlan_load').style.visibility = "visible";
    document.getElementById('essid_dropdown').style.visibility = "visible";
});

document.getElementById('essid').addEventListener("focusout", (event) => {
    focus_flag = false;
    const dropdown = document.getElementById('essid_dropdown')
    if (event.relatedTarget != dropdown) {
        dropdown.style.visibility = "hidden";
    }
});

document.getElementById('essid_dropdown').addEventListener("focusout", (event) => {
    document.getElementById('essid_dropdown').style.visibility = "hidden";
});

function change_essid () {
    document.getElementById('essid').value = document.querySelector('[name="essid_list"]:checked').value;
    document.getElementById('essid_dropdown').style.visibility = "hidden";
    essidSelect();
}
